X-Git-Url: https://git.rapsys.eu/airbundle/blobdiff_plain/301dffaba70eadd3e580427377fcfa0bcbdb159f..8f757e868d17f50a93f02bfbcdfc7125686514f9:/Controller/ApplicationController.php

diff --git a/Controller/ApplicationController.php b/Controller/ApplicationController.php
index 7cb9d97..deab095 100644
--- a/Controller/ApplicationController.php
+++ b/Controller/ApplicationController.php
@@ -3,6 +3,7 @@
 namespace Rapsys\AirBundle\Controller;
 
 use Symfony\Component\HttpFoundation\Request;
+use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\Routing\RequestContext;
 use Symfony\Component\Form\FormError;
 use Symfony\Component\Routing\Exception\MethodNotAllowedException;
@@ -28,11 +29,6 @@ class ApplicationController extends DefaultController {
 		//Prevent non-guest to access here
 		$this->denyAccessUnlessGranted('ROLE_GUEST', null, $this->translator->trans('Unable to access this page without role %role%!', ['%role%' => $this->translator->trans('Guest')]));
 
-		//Reject non post requests
-		if (!$request->isMethod('POST')) {
-			throw new \RuntimeException('Request method MUST be POST');
-		}
-
 		//Create ApplicationType form
 		$form = $this->createForm('Rapsys\AirBundle\Form\ApplicationType', null, [
 			//Set the action
@@ -52,12 +48,12 @@ class ApplicationController extends DefaultController {
 		$form->handleRequest($request);
 
 		//Handle invalid form
-		if (!$form->isValid()) {
+		if (!$form->isSubmitted() || !$form->isValid()) {
 			//Set section
 			$section = $this->translator->trans('Application add');
 
 			//Set title
-			$title = $section.' - '.$this->translator->trans($this->config['site']['title']);
+			$title = $this->translator->trans($this->config['site']['title']).' - '.$section;
 
 			//Render the view
 			return $this->render('@RapsysAir/application/add.html.twig', ['title' => $title, 'section' => $section, 'form' => $form->createView()]+$this->context);
@@ -129,21 +125,24 @@ class ApplicationController extends DefaultController {
 					$session->setLength(new \DateTime('05:00:00'));
 				//Check if afternoon
 				} elseif ($slot == 'Afternoon') {
-					//Set begin at 14h
-					$session->setBegin(new \DateTime('14:00:00'));
+					//Set begin at 16h
+					$session->setBegin(new \DateTime('16:00:00'));
 
-					//Set length at 5h
-					$session->setLength(new \DateTime('05:00:00'));
+					//Set length at 3h
+					$session->setLength(new \DateTime('03:00:00'));
 				//Check if evening
 				} elseif ($slot == 'Evening') {
-					//Set begin at 19h
-					$session->setBegin(new \DateTime('19:00:00'));
+					//Set begin at 20h30
+					$session->setBegin(new \DateTime('20:30:00'));
 
 					//Check if next day is premium
 					if ($premium) {
 						//Set length at 7h
 						$session->setLength(new \DateTime('07:00:00'));
 					}
+
+					//Set length at 4h
+					$session->setLength(new \DateTime('04:30:00'));
 				//Check if after
 				} else {
 					//Set begin at 1h
@@ -281,6 +280,13 @@ class ApplicationController extends DefaultController {
 
 				//Set length at 4h
 				$session->setLength(new \DateTime('04:00:00'));
+			//Jardin du Monde => 14h -> 15h
+			} elseif ($short == 'Monde' && $slot == 'Morning') {
+				//Set begin at 14h
+				$session->setBegin(new \DateTime('14:00:00'));
+
+				//Set length at 4h
+				$session->setLength(new \DateTime('01:00:00'));
 			//Combination not supported
 			} else {
 				//Add error in flash message
@@ -290,7 +296,7 @@ class ApplicationController extends DefaultController {
 				$section = $this->translator->trans('Application add');
 
 				//Set title
-				$title = $section.' - '.$this->translator->trans($this->config['site']['title']);
+				$title = $this->translator->trans($this->config['site']['title']).' - '.$section;
 
 				//Render the view
 				return $this->render('@RapsysAir/application/add.html.twig', ['title' => $title, 'section' => $section, 'form' => $form->createView()]+$this->context);
@@ -305,7 +311,7 @@ class ApplicationController extends DefaultController {
 				$section = $this->translator->trans('Application add');
 
 				//Set title
-				$title = $section.' - '.$this->translator->trans($this->config['site']['title']);
+				$title = $this->translator->trans($this->config['site']['title']).' - '.$section;
 
 				//Render the view
 				return $this->render('@RapsysAir/application/add.html.twig', ['title' => $title, 'section' => $section, 'form' => $form->createView()]+$this->context);
@@ -411,7 +417,7 @@ class ApplicationController extends DefaultController {
 				//Generate url
 				return $this->redirectToRoute($name, $route);
 			//No route matched
-			} catch(MethodNotAllowedException|ResourceNotFoundException $e) {
+			} catch (MethodNotAllowedException|ResourceNotFoundException $e) {
 				//Unset referer to fallback to default route
 				unset($referer);
 			}